@@ -8,13 +8,15 @@ OD_SIDE_CALIBRATION_FILENAME = "od_side_calibration_data.csv"
 
 
 class ODmeasurement:
-    def __init__(self, pe):
+    def __init__(self, pe, fit_functions=True):
         self.pe = pe
         self.dev = pe.dev
         self.calibration_file_front = os.path.join(self.pe.name, OD_FRONT_CALIBRATION_FILENAME)
         self.calibration_file_side = os.path.join(self.pe.name, OD_SIDE_CALIBRATION_FILENAME)
         if os.path.exists(self.calibration_file_front):
-            self.calibration_functions = [self.fit_calibration_curve(t) for t in range(7)]
+            df = pd.read_csv(self.calibration_file_front, index_col=0)
+            if not any(np.isnan(df.values.ravel())):
+                self.calibration_functions = [self.fit_calibration_curve(t) for t in range(7)]
 
     def collect_calibration_data(self, calibration_OD_values=None, starting_index=0):
 
@@ -34,7 +36,7 @@ class ODmeasurement:
                     self.pe.mix(100)
                     time.sleep(3)
                     self.pe.mix(0)
-                    time.sleep(0.5)
+                    time.sleep(3)
                     IFS, ISS = self.pe.Photodiodes.measure_current(t)
                     CurrentFront.loc[calibration_OD_values[(i + t) % 7], t] = IFS
                     CurrentSide.loc[calibration_OD_values[(i + t) % 7], t] = ISS
@@ -45,7 +47,8 @@ class ODmeasurement:
             print("Done collecting calibration data!")
 
     def fit_calibration_curve(self, tube=0):
-        df = pd.read_csv(self.calibration_file_front)
+        df = pd.read_csv(self.calibration_file_front, index_col=0)
+        df.columns=df.columns.astype(int)
         current = df.loc[:, tube]
         OD = np.array(df.index).ravel()
         x = np.log(current)
